#
# spec file for package popt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           popt
Version:        1.16
Release:        lp150.2.15
#!BuildIgnore:  rpmlint-Factory
Summary:        A C library for parsing command line parameters
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://www.rpm5.org/

#CVS-Clone:	-d :pserver:anonymous@rpm5.org:/cvs co popt
Source:         http://rpm5.org/files/popt/popt-%{version}.tar.gz
Source2:        baselibs.conf
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Patch0:         popt-libc-updates.patch
Patch1:         popt-alignment-checks.patch

%description
Popt is a C library for parsing command line parameters.  Popt was
heavily influenced by the getopt() and getopt_long() functions. It
improves on them by allowing more powerful argument expansion. Popt can
parse arbitrary argv[] style arrays and automatically set variables
based on command line arguments.  Popt allows command line arguments to
be aliased via configuration files and includes utility functions for
parsing arbitrary strings into argv[] arrays using shell-like rules.

%package -n libpopt0
Summary:        A C library for parsing command line parameters
Group:          System/Libraries
Provides:       popt = %{version}
Obsoletes:      popt < %{version}

%description -n libpopt0
Popt is a C library for parsing command line parameters.  Popt was
heavily influenced by the getopt() and getopt_long() functions. It
improves on them by allowing more powerful argument expansion. Popt can
parse arbitrary argv[] style arrays and automatically set variables
based on command line arguments.  Popt allows command line arguments to
be aliased via configuration files and includes utility functions for
parsing arbitrary strings into argv[] arrays using shell-like rules.

%package devel
Summary:        Development files for the popt library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libpopt0 = %{version}

%description devel
The popt-devel package includes header files and libraries necessary
for developing programs which use the popt C library. It contains the
API documentation of the popt library, too.

%prep
%setup -q
%patch0
%patch1 -p1

%build
autoreconf -fiv
%configure --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm %{buildroot}%{_libdir}/libpopt.la

%if "%{_libdir}" != "%{_prefix}/lib"
install -d -m755 %{buildroot}/%{_libdir}/pkgconfig
mv %{buildroot}%{_prefix}/lib/pkgconfig/%{name}.pc %{buildroot}/%{_libdir}/pkgconfig/%{name}.pc
%endif

%find_lang %{name}

%post -n libpopt0 -p /sbin/ldconfig

%postun -n libpopt0 -p /sbin/ldconfig

%files -n libpopt0 -f %{name}.lang
%defattr(-,root,root)
%license COPYING
%doc CHANGES
%{_libdir}/libpopt.so.*

%files devel
%defattr(-,root,root)
%doc README
%{_libdir}/libpopt.so
%{_includedir}/popt.h
%{_mandir}/man3/popt.3*
%{_libdir}/pkgconfig/popt.pc

%changelog
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Tue Aug  8 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs.
- Fix RPM groups.
* Mon Oct  7 2013 schwab@suse.de
- popt-alignment-checks.patch: fix alignment checks
* Sun Jul  7 2013 jengelh@inai.de
- Fix typo in popt-libc-updates.patch that prevented it to work
  with glibc before 2.17.
- More robust make install call; remove redundant %%clean section
* Fri Jun 14 2013 coolo@suse.com
- fix popt-libc-updates.patch to work also with automake 1.13
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Feb 13 2013 crrodriguez@opensuse.org
- Remove patches:
  - config-guess-sub-update.patch
  - popt-secure-getenv.patch
  run autoreconf instead .
- popt-libc-updates.patch replaces popt-secure-getenv.patch
  * test for secure_getenv instead of __secure_getenv
  * update configure.ac so it can be regenerated with modern
    autotools.
  * Internal symbols are already hidden with a linker script,
  improve that by hidding symbols with the compiler too.
  * use strerror_r instead of strerror in the library.
* Mon Feb 11 2013 crrodriguez@opensuse.org
- popt wants __secure_getenv at configure time, but This
  function is no longer available as of glibc 2.17.
  test for secure_getenv() instead (popt-secure-getenv.patch)
* Mon Feb  4 2013 dmueller@suse.com
- Add config-guess-sub-update.patch:
  * Update config.guess/sub for AArch64
* Fri Jan 25 2013 cfarrell@suse.com
- license update: X11
  New spdx.org license list now contains an official entry for X11
* Wed Aug 22 2012 cfarrell@suse.com
- license update: SUSE-XFree86-1.0
  This is not the MIT license but rather the old version of the XFree86
  license (which is not upstream at spdx.org/Ãlicenses - hence the SUSE
  proprietary prefix)
* Sun Feb 12 2012 crrodriguez@opensuse.org
- Libraries back into %%{_libdir}, /usr merge project.
* Sun Oct  9 2011 jengelh@medozas.de
- Add pkgconfig to BuildRequires to get automatic pkgconfig(popt)
  provides
* Wed Feb  2 2011 andreas.hanke@gmx-topmail.de
- don't build libpopt.a
- don't list popt.mo files twice
* Sun Jan 16 2011 coolo@novell.com
- use %%find_lang
* Sun Sep 19 2010 dimstar@opensuse.org
- Update to version 1.16:
  + Include xcode prject files in distributed tar ball
  + Build system fixes
  + Provide popt.pc
  + Extended test suite
  + Various fixes
- Changes from version 1.15:
  + Build system fixes
  + avoid displaying --[no]nofoo with POPT_ARGFLAG_TOGGLE.
  + reserve a bit for --[no]opt prefix toggling.
  + trim out escaped newline(s) from file content, other fixes.
  + check/print argv[0] in --help for NULL.
  + misc fixes
- Changes from version 1.14:
  + Build system fixes
  + permit "#define POPT_fprintf fprintf" to lose the malloc'ing
    fprintf
  + Many fixes.
  + Updated translations
- Drop popt-1.13-popt_fprintf.diff: Should all be fixed upstream.
  In case POPT_fprintf really still does not suffice, we can just
  use "#define POPT_fprintf frptinf" and be set. The code is
  prepared for this override.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Wed Apr  7 2010 mls@suse.de
- make libpopt0-32bit obsolete popt-32bit [bnc#544964]
* Mon Feb  1 2010 jengelh@medozas.de
- remove sparcv9-specific baselib exceptions (not needed)
* Sat Dec 12 2009 jengelh@medozas.de
- enable parallel building
- add baselibs.conf as a source
- add baselibs for SPARC
* Fri Aug 28 2009 mrueckert@suse.de
- add back baselibs.conf. bootstrap done
* Fri Aug 28 2009 mrueckert@suse.de
- disable baselibs.conf for the moment
* Wed Aug 26 2009 mls@suse.de
- add baselibs.conf
* Fri Aug 21 2009 mls@suse.de
- initial release
